# Acknowledgments

*   [astral.sh] for providing great tools like [uv], [ruff], and [ty]
*   [Stefan Scherfke’s blog post on using trusted publishers]
*   [commitizen] (though not fully convinced by their philosophy)
    for the automatic version bump inspiration


* * *
[astral.sh]: https://astral.sh/
[uv]: https://docs.astral.sh/uv/
[ruff]: https://docs.astral.sh/ruff/
[ty]: https://github.com/astral-sh/ty
[Stefan Scherfke’s blog post on using trusted publishers]: https://stefan.sofa-rockers.org/2024/11/14/gitlab-trusted-publisher/
[commitizen]: https://commitizen-tools.github.io/commitizen/
